@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (c) 2014, The MITRE Corporation. All rights reserved.
+# Copyright (c) 2017, The MITRE Corporation. All rights reserved.
 # See LICENSE.txt for complete terms.
 
 """Creates the CybOX content for CybOX_Simple_Email_Instance.xml
@@ -9,13 +9,9 @@
 from cybox.core import Observables
 from cybox.objects.address_object import Address
 from cybox.objects.email_message_object import EmailMessage
-import cybox.utils
 
 
 def main():
-    NS = cybox.utils.Namespace("http://example.com/", "example")
-    cybox.utils.set_id_namespace(NS)
-
     m = EmailMessage()
     m.to = ["victim1@target.com", "victim2@target.com"]
     m.from_ = "attacker@example.com"
@@ -25,7 +21,7 @@ def main():
 
     m.add_related(a, "Received_From", inline=False)
 
-    print Observables([m, a]).to_xml()
+    print(Observables([m, a]).to_xml(encoding=None))
 
 
 if __name__ == "__main__":
